summaryrefslogtreecommitdiffstats
path: root/src/toplevel.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/toplevel.h')
-rw-r--r--src/toplevel.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/toplevel.h b/src/toplevel.h
index 8eb0243a..081ddcae 100644
--- a/src/toplevel.h
+++ b/src/toplevel.h
@@ -2,10 +2,10 @@
#define __TOPLEVEL_H__
#include "kdevmainwindow.h"
/**\brief This class handles the single object of type KDevMainWindow.
It is completely static (all methods and attributes).
*/
@@ -14,13 +14,13 @@ class TopLevel
{
public:
- static KDevMainWindow *getInstance(); //!< Get a pointer to the single KDevTopLevel object
+ static TDevMainWindow *getInstance(); //!< Get a pointer to the single KDevTopLevel object
static bool mainWindowValid();
- static void invalidateInstance(KDevMainWindow *instance); //!< Signal that the object has been (or is about to be) destroyed
+ static void invalidateInstance(TDevMainWindow *instance); //!< Signal that the object has been (or is about to be) destroyed
private:
- static KDevMainWindow *s_instance; //!< Pointer to the single KDevTopLevel object or 0L
+ static TDevMainWindow *s_instance; //!< Pointer to the single KDevTopLevel object or 0L
};
@@ -2,10 +2,10 @@
#define __TOPLEVEL_H__
-#include "kdevmainwindow.h"
+#include "tdevmainwindow.h"
-/**\brief This class handles the single object of type KDevMainWindow.
+/**\brief This class handles the single object of type TDevMainWindow.
It is completely static (all methods and attributes).
*/